C grcpar.F
C All parameters that users are allowed to change are given by subroutines
C in this file.
C----------------------------------------------------------------------------
C SUBROUTINE GRCPAR : BASES parameters.
C
C IBSWRT = 0 : Create a new output file.
C        = 1 : Use an existing output file; i.e. skip the integration.
C ICOUP      : Choice of the energy scale (Q^2) for couplings.
C              if ICOUP = 1  ==> Q^2 = s-hat of the hard interaction.
C                       = 2  ==> Q^2 = average mT^2  (<mT^2>).
C                       = 3  ==> Q^2 = total mT^2  (sum mT^2).
C                       = 4  ==> Q^2 = maximum mT^2  (max mT^2).
C                       = 5  ==> Q^2 = a constant value.
C                       = 6  ==> user-defined Q^2.
C IFACT      : Choice of the energy scale (Q^2) for PDF.
C              The definition is the same as icoup.
C              If this is not given explicitly,
C                       = 0  ==> same scale as "ICOUP".
C IGRCGEF    : ON/OFF: 0/1 for photon interference in Z/A productions.
C GRCQ       : Renormalization scale in GeV; effective only when ICOUP = 5.
C GRCFAQ     : Factorization scale in GeV; effective only when IFACT = 5.
C NCALL      : Number of sampling points in each iteration step.
C GRCFILE    : BASES output file name.
C----------------------------------------------------------------------------
C SUBROUTINE SETMAS : particle masses and widths.
C
C AMZ        : Z mass               AGZ        : Z width
C AMW        : W mass               AGW        : W width
C AMH        : SM Higgs mass        AGH        : SM Higgs width
C AMUQ(I) and AGUQ(I) for the up-type quarks (u, c and t), and AMDQ(I) and
C AGDQ(I) for the down-type quarks (d, s and b), respectively.
C----------------------------------------------------------------------------
C SUBROUTINE GRCUSRSETQ : user-defined energy scale.
C
C The definition is effective only when "ICOUP" or "IFACT" = 6.
C Users must set their-defined energy scale into "GRCQ" or "GRCFAQ".
C An example is shown to choose as Q = <mT> of top-quarks in the top pair 
C productions ([ISUB]=170).
C----------------------------------------------------------------------------
C SUBROUTINE GRCUSRCUT : user-defined kinematical cut.
C
C The returned argument is "IUSRCUT".
C If events pass their cuts, IUSRCUT = 0,
C       not pass             IUSRCUT = 1.
C Users must carefully check the convergence of the BASES iteration if they
C define a tight cut using this subroutine.
C----------------------------------------------------------------------------
C Processes inplemented in GR@PPA
C
C For generic W/Z + jets production,
C [ISUB] : 100 (pp(bar) -> W -> 2f)
C        : 101 (pp(bar) -> W(2f) + 1 jet )
C        : 102 (pp(bar) -> W(2f) + 2 jets)
C        : 103 (pp(bar) -> W(2f) + 3 jets)
C        : 110 (pp(bar) -> Z/A -> 2f)
C        : 111 (pp(bar) -> Z/A(2f) + 1 jet)
C        : 112 (pp(bar) -> Z/A(2f) + 2 jets)
C
C For bbbb processes,
C [ISUB] : 160 (pp(bar) -> h0(bb) + bb)
C        : 161 (pp(bar) -> Z/A(bb)+ bb)
C        : 162 (pp(bar) -> bbbb (QCD))
C        : 163 (pp(bar) -> h0(bb) + Z/A(bb))
C        : 164 (pp(bar) -> Z/A(bb)+ Z/A(bb))
C
C For top production processes,
C [ISUB] : 170 (pp(bar) ->(tt)-> b+W(2f)+b+W(2f))
C
C For diboson, ZZ, WW, ZW production,
C [ISUB] : 550 (qq -> Z/A(2f)+Z/A(2f)(ELWK4))
C        : 551 (qq -> W(2f) + W(2f) (ELWK4))
C        : 552 (qq -> Z/A(2f) + W(2f)(ELWK4))
C
C
C Details of the subprocesses,
C
C For bbbb processes,
C [ISUB] : 400 (gg -> h0(bb)+bb(Higgs2,QCD2))
C        : 401 (qq -> h0(bb)+bb(Higgs2,QCD2))
C        : 402 (gg -> Z/A(bb)+bb(ELWK2,QCD2))
C        : 403 (qq -> Z/A(bb)+bb(ELWK2,QCD2))
C        : 404 (qq -> bbbb (Higgs2,ELWK2))
C        : 405 (gg -> bbbb (QCD4))
C        : 406 (qq -> bbbb (QCD4))
C        : 407 (qq -> Z/A(bb)+Z/A(bb)(ELWK4))
C
C For top pair production processes,
C [ISUB] : 419 (gg ->(tt)-> b+W(2f)+b+W(2f))
C        : 420 (qq ->(tt)-> b+W(2f)+b+W(2f))
C
C For W + jets processes,
C [ISUB] : 421 (qq -> W -> 2f (ELWK2))
C        : 422 (qg -> W(2f) + q (ELWK2,QCD1))
C        : 423 (qq -> W(2f) + g (ELWK2,QCD1))
C        : 424 (qg -> W(2f) + qg(ELWK2,QCD2))
C        : 425 (qq -> W(2f) + qq(ELWK2,QCD2))
C        : 426 (qq -> W(2f) + gg(ELWK2,QCD2))
C        : 427 (gg -> W(2f) + qq(ELWK2,QCD2))
C        : 428 (qq -> W(2f) + qq(ELWK2,QCD2))
C        : 429 (qq -> W(2f) + qq(ELWK2,QCD2))
C        : 430 (qq -> W(2f) + qq(ELWK2,QCD2))
C        : 431 (qg -> W(2f) +qgg(ELWK2,QCD3))
C        : 432 (qg -> W(2f) +qqq(ELWK2,QCD3))
C        : 433 (qq -> W(2f) +qqg(ELWK2,QCD3))
C        : 434 (qq -> W(2f) +ggg(ELWK2,QCD3))
C        : 435 (gg -> W(2f) +qqg(ELWK2,QCD3))
C        : 436 (qq -> W(2f) +qqg(ELWK2,QCD3))
C        : 437 (qq -> W(2f) +qqg(ELWK2,QCD3))
C        : 438 (qq -> W(2f) +qqg(ELWK2,QCD3))
C
C For Z/A + jets processes,
C [ISUB] : 500 (qq -> Z/gamma* -> 2f (ELWK2))
C        : 501 (qg->Z/g(2f) + q (ELWK2,QCD1))
C        : 502 (qq->Z/g(2f) + g (ELWK2,QCD1))
C        : 503 (qg->Z/g(2f) + qg(ELWK2,QCD2))
C        : 504 (qq->Z/g(2f) + qq(ELWK2,QCD2))
C        : 505 (qq->Z/g(2f) + gg(ELWK2,QCD2))
C        : 506 (gg->Z/g(2f) + qq(ELWK2,QCD2))
C        : 507 (qq->Z/g(2f) + qq(ELWK2,QCD2))
C        : 508 (qq->Z/g(2f) + qq(ELWK2,QCD2))
C        : 509 (qq->Z/g(2f) + qq(ELWK2,QCD2))
C
C----------------------------------------------------------------------------
C Kinematical variables provided for user-defined routines.
C See the include file, grchad.inc, for the details.
C
C Four-momentum in the CM frame of the hard interaction
C   i = 1, 2       : initial-state particles
C   i = 3, up to 8 : final-state particles
C     PGRC(1,i)  : px of i-th particle in CM frame.
C     PGRC(2,i)  : py
C     PGRC(3,i)  : pz
C     PGRC(4,i)  : E
C
C Variables in the laboratory frame
C   initial-state particles (i = 1, 2)
C     PLGRC(1,i) : px
C     PLGRC(2,i) : py
C     PLGRC(3,i) : pz
C     PLGRC(4,i) : E
C   final-state particles (i = 3,...,8)
C     PLGRC(1,i) : pT
C     PLGRC(2,i) : phi
C     PLGRC(3,i) : pseudo-rapidity (eta)
C     PLGRC(4,i) : E
C----------------------------------------------------------------------------
C  _/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
C _/_/  Set Initial Parameter for Each Process  _/_/
C_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
      SUBROUTINE GRCPAR(ISUB,GRCFILE)
      IMPLICIT REAL*8(A-H,O-Z)

      PARAMETER (MXDIM = 50, NDMX = 50 )
      COMMON /BPARM1/ XL(MXDIM),XU(MXDIM),NDIM,NWILD,
     $     IG(MXDIM),NCALL

      INCLUDE 'grchad.inc'
      INTEGER ISUB
      CHARACTER GRCFILE*60

C...For generic W/Z + jets processes,
      IF (ISUB.EQ.100) THEN
         IBSWRT = 0
         ICOUP = 1
         INPFL = 5
         NCALL = 10000
         GRCFILE = 'bases_w0j'
      ENDIF
 
      IF (ISUB.EQ.101) THEN
         IBSWRT = 0
         ICOUP = 5
         GRCQ = 80.419D0
         INPFL = 5
         NCALL = 50000
         GRCFILE = 'bases_w1j'
      ENDIF
 
 
      IF (ISUB.EQ.102) THEN
         IBSWRT = 0
         ICOUP = 5
         GRCQ = 80.419D0
         INPFL = 5
         NCALL = 1000000
         GRCFILE = 'bases_w2j'
      ENDIF
 
      IF (ISUB.EQ.103) THEN
         IBSWRT = 0
         ICOUP = 5
         GRCQ = 80.419D0
         INPFL = 5
         NCALL = 3000000
         GRCFILE = 'bases_w3j'
      ENDIF
 
      IF (ISUB.EQ.110) THEN
         IBSWRT = 0
         IGRCGEF = 1
         ICOUP = 1
         INPFL = 5
         NCALL = 50000
         GRCFILE = 'bases_z0j'
      ENDIF
 
      IF (ISUB.EQ.111) THEN
         IBSWRT = 0
         IGRCGEF = 1
         ICOUP = 5
         GRCQ = 91.188D0
         INPFL = 5
         NCALL = 100000
         GRCFILE = 'bases_z1j'
      ENDIF
 
      IF (ISUB.EQ.112) THEN
         IBSWRT = 0
         IGRCGEF = 1
         ICOUP = 5
         GRCQ = 91.188D0
         INPFL = 5
         NCALL = 1000000
         GRCFILE = 'bases_z2j'
      ENDIF
 
C...For bbbb processes,
      IF (ISUB.EQ.160) THEN
         IBSWRT = 0
         ICOUP = 5
         GRCQ = 120.0D0
         NCALL = 300000
         GRCFILE = 'bases_hbb_mh120'
      ENDIF
 
      IF (ISUB.EQ.161) THEN
         IBSWRT = 0
         ICOUP = 5
         GRCQ = 91.187D0
         NCALL = 5000000
         GRCFILE = 'bases_zbb'
      ENDIF
 
      IF (ISUB.EQ.162) THEN
         IBSWRT = 0
         ICOUP = 2
         NCALL = 500000
         GRCFILE = 'bases_qcd'
      ENDIF
 
      IF (ISUB.EQ.163) THEN
         IBSWRT = 0
         ICOUP = 5
         GRCQ = SQRT(120.0D0**2 + 91.187D0**2)
         NCALL = 20000
         GRCFILE = 'bases_hz_mh120'
      ENDIF
 
      IF (ISUB.EQ.164) THEN
         IBSWRT = 0
         ICOUP = 5
         GRCQ = SQRT(2.0D0)*91.187D0
         NCALL = 100000
         GRCFILE = 'bases_4bzz'
      ENDIF
 
C...For top pair production.
      IF (ISUB.EQ.170) THEN
         IBSWRT = 0
         ICOUP = 6
         NCALL = 50000
         GRCFILE = 'bases_top'
      ENDIF
 
C...For diboson processes,
      IF (ISUB.EQ.550) THEN
         IBSWRT = 0
         IGRCGEF = 1
         ICOUP = 5
         GRCQ = SQRT(2.0D0)*90.187D0
         INPFL = 5
         NCALL = 200000
         GRCFILE = 'bases_zz'
      ENDIF
 
      IF (ISUB.EQ.551) THEN
         IBSWRT = 0
         ICOUP = 5
         GRCQ = SQRT(2.0D0)*80.419
         INPFL = 5
         NCALL = 100000
         GRCFILE = 'bases_ww'
      ENDIF
 
      IF (ISUB.EQ.552) THEN
         IBSWRT = 0
         IGRCGEF = 0
         ICOUP = 5
         GRCQ = SQRT(80.419**2+90.187**2)
         INPFL = 5
         NCALL = 200000
         GRCFILE = 'bases_zw'
      ENDIF
 
      RETURN
      END
 
C  _/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
C _/_/  Set Mass, Width and some Parameters _/_/
C_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
      SUBROUTINE SETMAS
      IMPLICIT REAL*8(A-H,O-Z)
      INCLUDE 'inclm.h'
      INCLUDE 'inclc.h'
 
C...Constants
      PI    = ACOS(- 1.0D0 )    ! pi
      PI2   = PI*PI             ! pi**2
      RAD   = PI/180.0D0        ! radian
      GEVPB = 0.38937966D9      ! GeV -> pb
 
C...Some paramters are re-calculated according to the option IGAUGE and ICOUP.
      ALPHA = 1.0D0/128.07D0    ! alpha_em(Mz)
      ALPHAS= 0.130D0           ! alpha_s (dummy)
      ALPHA0= 1.0D0/137.036D0   ! alpha_em(Q=0)
      GF    = 1.16639D-5        ! Fermi constant
      STH2  = 0.231D0           ! sin^2(theta_w)
 
C...Set Mass
      AMW = 80.419D0            ! W
      AMZ = 91.188D0            ! Z
      AMA = 0.0D0               ! photon
      AMG = 0.0D0               ! gluon
      AMH = 120.0D0             ! SM Higgs
CCC   AMH = 80.0D0
CCC   AMH = 160.0D0
 
      AMNU(1) = 0.0D0           ! electron neutrino
      AMNU(2) = 0.0D0           ! muon neutrino
      AMNU(3) = 0.0D0           ! tau neutrino
      AMLP(1) = 0.51099906D-3   ! electron
      AMLP(2) = 105.658389D-3   ! muon
      AMLP(3) = 1.7771D0        ! tau
 
      AMUQ(1) = 2.0D-3          ! u quark
      AMUQ(2) = 1.5D0           ! c quark
      AMUQ(3) = 175.0D0         ! t quark
      AMDQ(1) = 5.0D-3          ! d quark
      AMDQ(2) = 0.5D0           ! s quark
      AMDQ(3) = 4.75D0          ! b quark
 
C...Set Width
CCC   AGW = 2.1200d0            ! W from experiment.
      AGW = 2.048D0             ! W
      AGZ = 2.446D0             ! Z
 
      AGH = 6.5378773D-3        ! SM Higgs (Mh = 120 GEV)
CCC   AGH = 4.1610854d-3       ! SM Higgs (Mh = 80 GeV)
CCC   AGH = 6.0677468d-2       ! SM Higgs (Mh = 160 GeV)

      AGUQ(1) = 0.0D0           ! u quark
      AGUQ(2) = 0.0D0           ! c quark
      AGUQ(3) = 1.586882D0      ! t quark
      AGDQ(1) = 0.0D0           ! d quark
      AGDQ(2) = 0.0D0           ! s quark
      AGDQ(3) = 0.001D0         ! b quark
 
      RETURN
      END
 
 
C  _/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
C _/_/  Set User Defined Energy Scale   _/_/
C_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
      SUBROUTINE GRCUSRSETQ
      IMPLICIT REAL*8(A-H,O-Z)
      INCLUDE 'grchad.inc'

C...User-defined energy scale.
C
C   The definition is effective only when "ICOUP" or "IFACT" = 6.
C   Users must set their-defined energy scale into "GRCQ" or "GRCFAQ".
C
C...4-momentum in the CM frame of the hard interaction
C   PGRC(i,j)  (i=1,4:(px,py,pz,E)): 4-momentum of j-th particle.
C   PQGRC(i,j) (i=1,4:(px,py,pz,E)): 4-momentum of j-th resonance particle.
C
C   This example shows the way to take the avarage transeverse mass of two 
C   top-quark invariant system as the renormalization/factrization scale in 
C   the top pair productions (ISUB=170).
C
C   For 6-body kinematics, 4-momenta of (anti-)top quark are given in
C   a parameters : PQGRC(i,1) and PQGRC(i,2).

C...Top pT^2.
      PT2 = PQGRC(1,1)**2 + PQGRC(2,1)**2

C...Top p.
      TP1 = SQRT(PQGRC(1,1)**2+PQGRC(2,1)**2+PQGRC(3,1)**2)
      TP2 = SQRT(PQGRC(1,2)**2+PQGRC(2,2)**2+PQGRC(3,2)**2)

C...Top and Anti-top mass.
      TMAS  = SQRT(PQGRC(4,1)**2-TP1**2)
      TAMAS = SQRT(PQGRC(4,2)**2-TP2**2)

C...Avarage transeverse mass.
      GRCQ = SQRT((2.0D0*PT2 + TMAS + TAMAS)/2.0D0)
      GRCFAQ = GRCQ

      RETURN
      END
 
C  _/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
C _/_/  Set User Defined Cut  _/_/
C_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
      SUBROUTINE GRCUSRCUT(IUSRCUT)
      IMPLICIT REAL*8(A-H,O-Z)
      INCLUDE 'grchad.inc'
      INTEGER IUSRCUT

C...User-defined kinematic cuts.
C
C   The returned argument is "IUSRCUT".
C   If events pass their cuts, IUSRCUT = 0,
C         not pass             IUSRCUT = 1.
C
C   Users must carefully check the convergence of the BASES iteration 
C   if they define a tight cut using this subroutine.
C
C...4-momentum in the CM frame of the hard interaction
C     PGRC(I,J)  (I=1,4:(px,py,pz,E))  : 4-momentum of J-th particle.
C
C...4-momentum in the Laboratory frame.
C     PLGRC(I,J) (I=1,4:(pT,phi,eta,E)): 4-momentum of J-th (J > 2) 
C                                        final state particle.
C
C...Useful stuff.
C     FUNCTION GRCKFCD(I)   : Output particle identification code.
C     FUNCTION GRCIVMS(I,J) : Output inv. mass between "I" and "J" particles.
C     FUNCTION GRCDPHI(I,J) : Output Delta Phi between "I" and "J" particles.
C     FUNCTION GRCDRCN(I,J) : Output Delta R between "I" and "J" particles.
C
CCCC   This example shows the cuts of pT > 20 GeV and DeltaR > 0.4 only for 
CCCC   light flavors from top decay, but not applied the b-quarks from top.
CCC
CCCC...Initialzation.
CCC      IUSRCUT = 0
CCC
CCCC...Set cut vatiable.
CCC      PTCUT = 20.0D0
CCC      DRCUT = 0.4D0
CCC
CCCC...Look for light flavor, then check the kinematics.
CCC      DO I = 3,8
CCC         ID = GRCKFCD(I)
CCC         IF (IABS(ID).LT.5) THEN
CCC            IF (PLGRC(1,I).LT.PTCUT) IUSRCUT = 1
CCC            DO J = 3,8
CCC               IF (J.NE.I.AND.GRCDRCN(I,J).LT.DRCUT) IUSRCUT = 1
CCC            ENDDO
CCC         ENDIF
CCC      ENDDO

      IUSRCUT = 0
 
      RETURN
      END
 
